@@ -10,11 +10,11 @@
 module Annex.Ssh (
 	sshCachingOptions,
 	sshCleanup,
+	sshCacheDir,
 	sshReadPort,
 ) where
 
 import qualified Data.Map as M
-import System.Posix.Env
 
 import Common.Annex
 import Annex.LockPool
@@ -22,6 +22,7 @@ import Annex.Perms
 import qualified Build.SysConfig as SysConfig
 import qualified Annex
 import Config
+import Utility.Env
 
 {- Generates parameters to ssh to a given host (or user@host) on a given
  - port, with connection caching. -}
@@ -95,6 +96,7 @@ sshCleanup = go =<< sshCacheDir
 			liftIO (catchDefaultIO [] $ dirContents dir)
 		forM_ sockets cleanup
 	cleanup socketfile = do
+#ifndef __WINDOWS__
 		-- Drop any shared lock we have, and take an
 		-- exclusive lock, without blocking. If the lock
 		-- succeeds, nothing is using this ssh, and it can
@@ -110,6 +112,9 @@ sshCleanup = go =<< sshCacheDir
 			Left _ -> noop
 			Right _ -> stopssh socketfile
 		liftIO $ closeFd fd
+#else
+		stopssh socketfile
+#endif
 	stopssh socketfile = do
 		let (host, port) = socket2hostport socketfile
 		(_, params) <- sshInfo (host, port)
