@@ -5,6 +5,8 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
+{-# LANGUAGE CPP #-}
+
 module Init (
 	ensureInitialized,
 	isInitialized,
@@ -14,8 +16,9 @@ module Init (
 ) where
 
 import Common.Annex
-import Utility.TempFile
+import Utility.Tmp
 import Utility.Network
+import qualified Annex
 import qualified Git
 import qualified Git.LsFiles
 import qualified Git.Config
@@ -34,11 +37,15 @@ import Backend
 genDescription :: Maybe String -> Annex String
 genDescription (Just d) = return d
 genDescription Nothing = do
+	reldir <- liftIO . relHome =<< fromRepo Git.repoPath
 	hostname <- fromMaybe "" <$> liftIO getHostname
+#ifndef __WINDOWS__
 	let at = if null hostname then "" else "@"
 	username <- liftIO myUserName
-	reldir <- liftIO . relHome =<< fromRepo Git.repoPath
 	return $ concat [username, at, hostname, ":", reldir]
+#else
+	return $ concat [hostname, ":", reldir]
+#endif
 
 initialize :: Maybe String -> Annex ()
 initialize mdescription = do
@@ -106,13 +113,18 @@ preCommitHook = (</>) <$> fromRepo Git.localGitDir <*> pure "hooks/pre-commit"
 
 preCommitScript :: String
 preCommitScript = unlines
-	[ shebang
+	[ shebang_local
 	, "# automatically configured by git-annex"
 	, "git annex pre-commit ."
 	]
 
+{- A crippled filesystem is one that does not allow making symlinks,
+ - or removing write access from files. -}
 probeCrippledFileSystem :: Annex Bool
 probeCrippledFileSystem = do
+#ifdef __WINDOWS__
+	return True
+#else
 	tmp <- fromRepo gitAnnexTmpDir
 	let f = tmp </> "gaprobe"
 	liftIO $ do
@@ -132,11 +144,21 @@ probeCrippledFileSystem = do
 		preventWrite f
 		allowWrite f
 		return True
+#endif
 
 checkCrippledFileSystem :: Annex ()
 checkCrippledFileSystem = whenM probeCrippledFileSystem $ do
 	warning "Detected a crippled filesystem."
 	setCrippledFileSystem True
+
+	{- Normally git disables core.symlinks itself when the filesystem does
+ 	 - not support them, but in Cygwin, git does support symlinks, while
+ 	 - git-annex, not linking with Cygwin, does not. -}
+	whenM (coreSymlinks <$> Annex.getGitConfig) $ do
+		warning "Disabling core.symlinks."
+		setConfig (ConfigKey "core.symlinks")
+			(Git.Config.boolConfig False)
+
 	unlessM isDirect $ do
 		warning "Enabling direct mode."
 		top <- fromRepo Git.repoPath
@@ -149,6 +171,9 @@ checkCrippledFileSystem = whenM probeCrippledFileSystem $ do
 
 probeFifoSupport :: Annex Bool
 probeFifoSupport = do
+#ifdef __WINDOWS__
+	return False
+#else
 	tmp <- fromRepo gitAnnexTmpDir
 	let f = tmp </> "gaprobe"
 	liftIO $ do
@@ -159,6 +184,7 @@ probeFifoSupport = do
 			getFileStatus f
 		nukeFile f
 		return $ either (const False) isNamedPipe ms
+#endif
 
 checkFifoSupport :: Annex ()
 checkFifoSupport = unlessM probeFifoSupport $ do
